@@ -64,7 +64,8 @@
     }
 
   # Check if input to factor_corres is correct
-  checkmate::assert_numeric(factor_corres, null.ok = TRUE, len = nrow(g_load))
+  checkmate::assert_matrix(factor_corres, null.ok = TRUE, nrows = nrow(g_load),
+                           ncols = ncol(s_load))
 
   # Create an input dataframe
   input <- data.frame(g_load, s_load)
@@ -85,8 +86,16 @@
       }
 
     if(is.null(factor_corres)){
-      factor_corres <- apply(input, 1,
-                             function(x) which.max(abs(x[2:(ncol(s_load) + 1)])))
+
+      factor_corres <- matrix(0, nrow = nrow(s_load), ncol= ncol(s_load))
+
+      for(i in seq_len(nrow(s_load))){
+
+        factor_corres[i, which.max(abs(input[i, 2:(ncol(s_load) + 1)]))] <- 1
+
+      }
+
+
 
     } else {
 
@@ -95,13 +104,8 @@
   }
 
   input$u2 <- u2
-  input <- cbind(factor_corres, input)
-  names(input)[1] <- "factor"
 
-  # Create all sums of factor loadings for each factor
-
-  # Sums of all group factor loadings for each group factor
-  sums_s <- colSums(input[, 3:(ncol(s_load) + 2)])
+  omega_mat <- input[, 2:(ncol(s_load) + 1)] * factor_corres
 
   # Sum of all g loadings
   sum_g <- sum(input$g)
@@ -112,14 +116,14 @@
   # Compute sums of error variances and g-loadings for group factors
   sums_e_s <- NULL
   sums_g_s <- NULL
-  sums_s_s <- NULL
 
   for (i in seq_len(ncol(s_load))){
-    sums_e_s[i] <- sum(input[input$factor == i, "u2"])
-    sums_g_s[i] <- sum(input[input$factor == i, "g"])
-    sums_s_s[i] <- sum(input[input$factor == i, i + 2])
+    sums_e_s[i] <- sum(input$u2 * factor_corres[, i])
+    sums_g_s[i] <- sum(input$g * factor_corres[, i])
   }
 
+  sums_s_s <- colSums(omega_mat)
+
   if(variance == "correlation"){
 
     # Compute omega total, hierarchical, and subscale for g-factor
@@ -133,7 +137,7 @@
     omega_sub_sub <- NULL
 
     for (i in seq_len(ncol(s_load))) {
-      subf <- which(factor_corres == i)
+      subf <- which(factor_corres[, i] == 1)
       Vgr <- sum(cormat[subf, subf])
       omega_sub_sub[i] <- sums_s_s[i]^2 / Vgr
       omega_h_sub[i] <- sums_g_s[i]^2 / Vgr
@@ -142,6 +146,9 @@
 
   } else if(variance == "sums_load") {
 
+    # Sums of all group factor loadings for all group factors
+    sums_s <- colSums(input[, 2:(ncol(s_load) + 1)])
+
     # Compute omega total, hierarchical, and subscale for g-factor
     omega_tot_g <- (sum_g^2 + sum(sums_s_s^2)) / (sum_g^2 + sum(sums_s_s^2) +
                                                     sum_e)
