@@ -234,7 +234,8 @@ PARALLEL <- function(x = NULL,
     if ("PCA" %in% eigen_type) {
 
       eigvals_PCA <- try(future.apply::future_lapply(size_vec, .parallel_sim, N = N,
-                                             n_vars = n_vars, eigen_type = 1),
+                                             n_vars = n_vars, eigen_type = 1,
+                                             future.seed = TRUE),
                          silent = TRUE)
 
       it_i <- 1
@@ -242,7 +243,8 @@ PARALLEL <- function(x = NULL,
         eigvals_PCA <- try(future.apply::future_lapply(size_vec, .parallel_sim,
                                                        N = N,
                                                        n_vars = n_vars,
-                                                       eigen_type = 1),
+                                                       eigen_type = 1,
+                                                       future.seed = TRUE),
                            silent = TRUE)
         it_i <- it_i + 1
       }
@@ -278,14 +280,18 @@ PARALLEL <- function(x = NULL,
 
       eigvals_SMC <- try(future.apply::future_lapply(size_vec, .parallel_sim,
                                                      N = N, n_vars = n_vars,
-                                                     eigen_type = 2),
+                                                     eigen_type = 2,
+                                                     maxit = n_datasets * 10,
+                                                     future.seed = TRUE),
                          silent = TRUE)
       it_i <- 1
       while (inherits(eigvals_SMC, "try-error") && it_i < 25) {
         eigvals_SMC <- try(future.apply::future_lapply(size_vec, .parallel_sim,
                                                        N = N,
                                                        n_vars = n_vars,
-                                                       eigen_type = 2),
+                                                       eigen_type = 2,
+                                                       maxit = n_datasets * 10,
+                                                       future.seed = TRUE),
                            silent = TRUE)
         it_i <- it_i + 1
       }
@@ -320,7 +326,8 @@ PARALLEL <- function(x = NULL,
 
       eigvals_EFA <- future.apply::future_lapply(size_vec, .parallel_EFA_sim,
                                              n_vars = n_vars, N = N,
-                                             n_factors = n_factors, ...)
+                                             n_factors = n_factors, ...,
+                                             future.seed = TRUE)
       eigvals_EFA <- do.call(rbind, eigvals_EFA)
 
       results_EFA <- .parallel_summarise(eigvals_EFA, percent = percent,
