@@ -1,14 +1,14 @@
 ## Promax rotation
 .PROMAX <- function (x, type = c("EFAtools", "psych", "SPSS", "none"),
-                    normalize = TRUE, P_type = NULL, precision = 1e-5,
-                    order_type = NULL,  varimax_type = NULL, k = NULL) {
+                    normalize = TRUE, P_type = NA, precision = 1e-5,
+                    order_type = NA,  varimax_type = NA, k = NA) {
 
   if (type == "none") {
     # if type is none, throw an error if not
     # all the other necessary arguments are specified.
 
-    if (is.null(P_type) || is.null(order_type) || is.null(varimax_type) || is.null(k)) {
-      stop(crayon::red$bold(cli::symbol$circle_cross), crayon::red(' One of "P_type", "order_type", "varimax_type", or "k" was NULL and no valid "type" was specified. Either use one of "EFAtools", "psych", or "SPSS" for type, or specify all other arguments\n'))
+    if (is.na(P_type) || is.na(order_type) || is.na(varimax_type) || is.na(k)) {
+      stop(crayon::red$bold(cli::symbol$circle_cross), crayon::red(' One of "P_type", "order_type", "varimax_type", or "k" was NA and no valid "type" was specified. Either use one of "EFAtools", "psych", or "SPSS" for type, or specify all other arguments\n'))
     }
   } else if (type == "EFAtools") {
 
@@ -20,25 +20,25 @@
       warning(crayon::yellow$bold("!"), crayon::yellow(" Type and normalize is specified. normalize is used with value '", normalize, "'. Results may differ from the specified type\n"))
     }
 
-    if (is.null(P_type)) {
+    if (is.na(P_type)) {
       P_type <- "norm"
     } else {
       warning(crayon::yellow$bold("!"), crayon::yellow(" Type and P_type is specified. P_type is used with value '", P_type, "'. Results may differ from the specified type\n"))
     }
 
-    if (is.null(order_type)) {
+    if (is.na(order_type)) {
       order_type <- "eigen"
     } else {
       warning(crayon::yellow$bold("!"), crayon::yellow(" Type and order_type is specified. order_type is used with value '", order_type, "'. Results may differ from the specified type\n"))
     }
 
-    if (is.null(varimax_type)) {
+    if (is.na(varimax_type)) {
       varimax_type <- "svd"
     } else {
       warning(crayon::yellow$bold("!"), crayon::yellow(" Type and varimax_type is specified. varimax_type is used with value '", varimax_type, "'. Results may differ from the specified type\n"))
     }
 
-    if (is.null(k)) {
+    if (is.na(k)) {
       k <- 4
     } else {
       warning(crayon::yellow$bold("!"), crayon::yellow(" Type and k is specified. k is used with value '", k, "'. Results may differ from the specified type\n"))
@@ -55,25 +55,25 @@
       warning(crayon::yellow$bold("!"), crayon::yellow(" Type and normalize is specified. normalize is used with value '", normalize, "'. Results may differ from the specified type.\n"))
     }
 
-    if (is.null(P_type)) {
+    if (is.na(P_type)) {
       P_type <- "unnorm"
     } else {
       warning(crayon::yellow$bold("!"), crayon::yellow(" Type and P_type is specified. P_type is used with value '", P_type, "'. Results may differ from the specified type\n"))
     }
 
-    if (is.null(order_type)) {
+    if (is.na(order_type)) {
       order_type <- "eigen"
     } else {
       warning(crayon::yellow$bold("!"), crayon::yellow(" Type and order_type is specified. order_type is used with value '", order_type, "'. Results may differ from the specified type\n"))
     }
 
-    if (is.null(varimax_type)) {
+    if (is.na(varimax_type)) {
       varimax_type <- "svd"
     } else {
       warning(crayon::yellow$bold("!"), crayon::yellow(" Type and varimax_type is specified. varimax_type is used with value '", varimax_type, "'. Results may differ from the specified type\n"))
     }
 
-    if (is.null(k)) {
+    if (is.na(k)) {
       k <- 4
     } else {
       warning(crayon::yellow$bold("!"), crayon::yellow(" Type and k is specified. k is used with value '", k, "'. Results may differ from the specified type\n"))
@@ -90,25 +90,25 @@
       warning(crayon::yellow$bold("!"), crayon::yellow(" Type and normalize is specified. normalize is used with value '", normalize, "'. Results may differ from the specified type.\n"))
     }
 
-    if (is.null(P_type)) {
+    if (is.na(P_type)) {
       P_type <- "norm"
     } else {
       warning(crayon::yellow$bold("!"), crayon::yellow(" Type and P_type is specified. P_type is used with value '", P_type, "'. Results may differ from the specified type\n"))
     }
 
-    if (is.null(order_type)) {
+    if (is.na(order_type)) {
       order_type <- "ss_factors"
     } else {
       warning(crayon::yellow$bold("!"), crayon::yellow(" Type and order_type is specified. order_type is used with value '", order_type, "'. Results may differ from the specified type\n"))
     }
 
-    if (is.null(varimax_type)) {
+    if (is.na(varimax_type)) {
       varimax_type <- "kaiser"
     } else {
       warning(crayon::yellow$bold("!"), crayon::yellow(" Type and varimax_type is specified. varimax_type is used with value '", varimax_type, "'. Results may differ from the specified type\n"))
     }
 
-    if (is.null(k)) {
+    if (is.na(k)) {
       k <- 4
     } else {
       warning(crayon::yellow$bold("!"), crayon::yellow(" Type and k is specified. k is used with value '", k, "'. Results may differ from the specified type\n"))
